
# Slot: local_name_value


a name assigned to an element in a given ontology

URI: [linkml:local_name_value](https://w3id.org/linkml/local_name_value)


## Domain and Range

[LocalName](LocalName.md) &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [LocalName](LocalName.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:altLabel |

